summaryrefslogtreecommitdiffstats
path: root/tests/badssl.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tests/badssl.sh')
-rwxr-xr-xtests/badssl.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/badssl.sh b/tests/badssl.sh
index 552bc2c..809a9f1 100755
--- a/tests/badssl.sh
+++ b/tests/badssl.sh
@@ -2,20 +2,20 @@
#
# Copyright (C) 2019 Libiquity LLC
#
# This file is part of wolfssl-util.
#
# wolfssl-util is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# wolfssl-util is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with wolfssl-util. If not, see <http://www.gnu.org/licenses/>.
+# along with wolfutil. If not, see <http://www.gnu.org/licenses/>.
set -eu
@@ -30,7 +30,7 @@ do_test()
shift 4
local result=
- if ${ok} "${TOP_BUILDDIR}/wolfssl" s_client \
+ if ${ok} "${TOP_BUILDDIR}/wolfutil" s_client \
-connect "${host}.badssl.com:${port}" \
-servername "${host}.badssl.com" \
<<-EOF
@@ -2,20 +2,20 @@
# Copyright (C) 2019 Libiquity LLC
#
-# This file is part of wolfssl-util.
+# This file is part of wolfutil.
#
@@ -2,20 +2,20 @@
#
-# wolfssl-util is free software: you can redistribute it and/or modify
+# wolfutil is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
@@ -2,20 +2,20 @@
# (at your option) any later version.
#
-# wolfssl-util is distributed in the hope that it will be useful,
+# wolfutil is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the